@@ -5,6 +5,7 @@ extends 'Math::Geometry::Construction::Derivate';
 use 5.008008;
 
 use Carp;
+use Math::VectorReal;
 
 =head1 NAME
 
@@ -12,11 +13,11 @@ C<Math::Geometry::Construction::Derivate::TranslatedPoint> - point translated by
 
 =head1 VERSION
 
-Version 0.007
+Version 0.010
 
 =cut
 
-our $VERSION = '0.007';
+our $VERSION = '0.010';
 
 
 ###########################################################################
@@ -29,6 +30,18 @@ has 'translator' => (isa      => 'Item',
 		     is       => 'rw',
 		     required => 1);
 
+sub BUILDARGS {
+    my ($class, %args) = @_;
+
+    if(defined($args{translator}) and ref($args{translator}) eq 'ARRAY') {
+	$args{translator} = vector($args{translator}->[0],
+				   $args{translator}->[1],
+				   $args{translator}->[2] || 0);
+    }
+
+    return \%args;
+}
+
 ###########################################################################
 #                                                                         #
 #                             Retrieve Data                               #
