@@ -73,17 +73,43 @@ __END__
 
 =head1 SYNOPSIS
 
+  use Math::Geometry::Construction;
+
+  my $construction = Math::Geometry::Construction->new;
+  my $p1 = $construction->add_point('x' => 100, 'y' => 150);
+  my $p2 = $construction->add_point('x' => 130, 'y' => 110);
+
+  my $l1 = $construction->add_line(extend  => 10,
+				   support => [$p1, $p2]);
+
+  my $tikz = $construction->as_tikz(width    => 8,
+                                    height   => 3,
+                                    view_box => [0, 0, 800, 300],
+                                    svg_mode => 1);
+
+  print $construction->as_svg(width => 800, height => 300)->xmlify;
+
 
 =head1 DESCRIPTION
 
+This class implements the
+L<Math::Geometry::Construction::Draw|Math::Geometry::Construction::Draw>
+interface in order to generate C<SVG> output. It is instantiated by
+the L<draw method|Math::Geometry::Construction/draw> in
+C<Math::Geometry::Construction>.
+
+The output created by this class will be an L<SVG|SVG> object. See
+C<SYNOPSIS>.
+
+Key/value pairs in the style settings of lines, circles etc. are
+passed unchanged to the respective C<SVG> element.
+
 
 =head1 INTERFACE
 
 =head2 Public Attributes
 
-=head2 Methods for Users
-
-=head2 Methods for Subclass Developers
+=head2 Methods
 
 =head1 DIAGNOSTICS
 
@@ -94,7 +120,22 @@ __END__
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported. Please report all bugs directly to the author.
+Please report any bugs or feature requests to
+C<bug-math-geometry-construction at rt.cpan.org>, or through the web
+interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Math-Geometry-Construction>.
+I will be notified, and then you will automatically be notified of
+progress on your bug as I make changes.
+
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<SVG|SVG>
+
+=item * L<http://www.w3.org/TR/SVG11/>
+
+=back
 
 
 =head1 AUTHOR
